==> mingw-w64-nodejs-21.7.1-2.src.tar.zst: node-v21.7.1/deps/v8/src/objects/dependent-code-inl.h <==
// Copyright 2023 the V8 project authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef V8_OBJECTS_DEPENDENT_CODE_INL_H_
#define V8_OBJECTS_DEPENDENT_CODE_INL_H_

#include "src/objects/dependent-code.h"
#include "src/objects/fixed-array-inl.h"
#include "src/objects/tagged.h"

// Has to be the last include (doesn't have include guards):
#include "src/objects/object-macros.h"

namespace v8 {
namespace internal {

OBJECT_CONSTRUCTORS_IMPL(DependentCode, WeakArrayList)
CAST_ACCESSOR(DependentCode)

// static
template <typename ObjectT>
void DependentCode::DeoptimizeDependencyGroups(Isolate* isolate, ObjectT object,
                                               DependencyGroups groups) {
  static_assert(kTaggedCanConvertToRawObjects);
  DeoptimizeDependencyGroups(isolate, Tagged<ObjectT>(object), groups);
}

// static
template <typename ObjectT>
void DependentCode::DeoptimizeDependencyGroups(Isolate* isolate,
                                               Tagged<ObjectT> object,
                                               DependencyGroups groups) {
  // Shared objects are designed to never invalidate code.
  DCHECK(!Object::InSharedHeap(object) && !object->InReadOnlySpace());
  object->dependent_code()->DeoptimizeDependencyGroups(isolate, groups);
}

// static
template <typename ObjectT>
bool DependentCode::MarkCodeForDeoptimization(Isolate* isolate,
                                              Tagged<ObjectT> object,
                                              DependencyGroups groups) {
  // Shared objects are designed to never invalidate code.
  DCHECK(!object.InAnySharedSpace() && !object.InReadOnlySpace());
  return object->dependent_code()->MarkCodeForDeoptimization(isolate, groups);
}

}  // namespace internal
}  // namespace v8

#include "src/objects/object-macros-undef.h"

#endif  // V8_OBJECTS_DEPENDENT_CODE_INL_H_

==> mingw-w64-nodejs-23.5.0-1.src.tar.zst: node-v23.5.0/deps/v8/src/objects/dependent-code-inl.h <==
// Copyright 2023 the V8 project authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef V8_OBJECTS_DEPENDENT_CODE_INL_H_
#define V8_OBJECTS_DEPENDENT_CODE_INL_H_

#include "src/objects/dependent-code.h"
#include "src/objects/fixed-array-inl.h"
#include "src/objects/tagged.h"

// Has to be the last include (doesn't have include guards):
#include "src/objects/object-macros.h"

namespace v8 {
namespace internal {

OBJECT_CONSTRUCTORS_IMPL(DependentCode, WeakArrayList)

// static
template <typename ObjectT>
void DependentCode::DeoptimizeDependencyGroups(Isolate* isolate, ObjectT object,
                                               DependencyGroups groups) {
  static_assert(kTaggedCanConvertToRawObjects);
  DeoptimizeDependencyGroups(isolate, Tagged<ObjectT>(object), groups);
}

// static
template <typename ObjectT>
void DependentCode::DeoptimizeDependencyGroups(Isolate* isolate,
                                               Tagged<ObjectT> object,
                                               DependencyGroups groups) {
  // Shared objects are designed to never invalidate code.
  DCHECK(!InAnySharedSpace(object) && !InReadOnlySpace(object));
  object->dependent_code()->DeoptimizeDependencyGroups(isolate, groups);
}

// static
template <typename ObjectT>
bool DependentCode::MarkCodeForDeoptimization(Isolate* isolate,
                                              Tagged<ObjectT> object,
                                              DependencyGroups groups) {
  // Shared objects are designed to never invalidate code.
  DCHECK(!InAnySharedSpace(object) && !InReadOnlySpace(object));
  return object->dependent_code()->MarkCodeForDeoptimization(isolate, groups);
}

}  // namespace internal
}  // namespace v8

#include "src/objects/object-macros-undef.h"

#endif  // V8_OBJECTS_DEPENDENT_CODE_INL_H_
